#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : __init__.py
# @Time         : 2023/7/5 15:28
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :


from chatllm.llmchain.applications.chatbase import ChatBase
from chatllm.llmchain.applications.chatfile import ChatFile

from chatllm.llmchain.applications.chatocr import ChatOCR
from chatllm.llmchain.applications.summarizer import Summarizer



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : completion
# @Time         : 2023/7/31 16:12
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :


from chatllm.llmchain.completions.ernie import ErnieBotCompletion
from chatllm.llmchain.completions.spark import SparkBotCompletion
from chatllm.llmchain.completions.chatglm import ChatGLMCompletion
